import React, { Component, Fragment } from 'react';
import moment from 'moment';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Modal, Button, message } from 'antd';
import { StandardTableList } from '../../components/RBList';
import { renderCategory, addRowKey } from '../../utils/utils';
import styles from './CampusList.less';

const Message = message;

@connect(({loading, campus}) => ({
  campus,
  loading: loading.models.campus,
}))
export default class CampusListPage extends Component {
  constructor(props) {
    super(props);
    const { state } = props.location;
    this.state = {
      UIParams: (state || {}).UIParams, // 组件的状态参数
      Queryers: (state || {}).Queryers, // 查询的条件参数
    };
  }
  componentDidMount() {
    this.props.dispatch({
      type: 'campus/fetchCampusList',
      payload: {...this.state.Queryers},
    });
  }
  handleCreateOperation = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/campus/create',
      state: this.state,
    }));
  }
  handleEditOperation = (item) => {
    this.props.dispatch(routerRedux.push({
      pathname: `/campus/edit/${item.id}`,
      state: this.state,
    }));
  }
  handleFilterOperation = (params, states) => {
    this.props.dispatch({
      type: 'campus/fetchCampusList',
      payload: params,
    });
    this.setState({
      UIParams: states,
      Queryers: params,
    });
  }
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  }

  render() {
    const { loading, campus } = this.props;
    const { list, totalSize, pageSize, pageNo } = campus;

    const renderOperation = (item) => {
      return (
        <div>
          <Button
            size="small"
            className={styles.editBtn}
            onClick={() => this.handleEditOperation(item)}
          >编辑
          </Button>
        </div>
      );
    }

    const batchActions = [{
      key: 'delete',
      name: '批量删除',
    }, {
      key: 'recovery',
      name: '批量恢复',
    }];
    const basicSearch = {
      keys: [{
        name: '校区编号',
        field: 'code',
      }, {
        name: '校区名称',
        field: 'name',
      }],
    };
    const pagination = {
      pageNo,
      pageSize,
      totalSize,
    };
    const columns = [{
      title: '校区编号',
      key: 1,
      dataIndex: 'code',
      render: (text, record) => (
        <a className={styles.link}
          onClick={() => this.handleEditOperation(record)}
        >
          {text}
        </a>
      ),
      width: '12%',
    }, {
      title: '校区名称',
      key: 2,
      dataIndex: 'name',
      render: (text, record) => (
        <a className={styles.link}
          onClick={() => this.handleEditOperation(record)}
        >
          {text}
        </a>
      ),
      width: '34%',
    }, {
      title: '所属渠道',
      key: 3,
      dataIndex: 'merchantName',
      width: '10%',
    }, {
      title: '校区联系人',
      key: 4,
      dataIndex: 'contactName',
      width: '10%',
    }, {
      title: '联系电话',
      key: 5,
      dataIndex: 'mobile',
      width: '12%',
    }, {
      title: '更新时间',
      key: 6,
      dataIndex: 'gmtModified',
      render: (text) => moment(text).format('YYYY-MM-DD HH:mm:ss'),
      width: '16%',
    }, {
      title: '操作',
      key: 7,
      dataIndex: 'operation',
      render: (_, record) => renderOperation(record),
      width: '6%',
    }];
    const renderAdvancedSearch = () => {
      return (
        <div>测试
        </div>
      );
    }
    return (
      <Fragment>
        <StandardTableList
          columns={columns}
          loading={loading}
          dataSource={addRowKey(list)}
          header={{
            basicSearch,
            advancedSearch: renderAdvancedSearch(),
            onFilterClick: this.handleFilterOperation,
            onCreateClick: this.handleCreateOperation,
          }}
          footer={{
            pagination,
            batchActions,
            onBatchClick: this.handleBatchOperation,
          }}
          keepUIState={{...this.state.UIParams}}
          showStatusSelect={false}
        />
      </Fragment>
    );
  }
}
